@@ -12,16 +12,17 @@
 # Public License Version 2, June 1991.  
 
 
-# Called as: WriteXLS.pl [--CSVpath] [--verbose] [--AdjWidth] [--AutoFilter] [--BoldHeaderRow] [-FreezeRow] [--FreezeCol] [--Encoding] [--AllText] ExcelFileName
+# Called as: WriteXLS.pl [--CSVpath] [--verbose] [--AdjWidth] [--AutoFilter] [--BoldHeaderRow] [--ReadOnly] [--FreezeRow] [--FreezeCol] [--Encoding] [--AllText] ExcelFileName
 
 # CSVpath = Path to CSV Files. Defaults to '.'
 # verbose = Output status messages. TRUE or FALSE. Defaults to FALSE
 # Adj.Width = Adjust column widths based upon longest entry in each column. Defaults to FALSE
 # AutoFilter = Set autofilter for each sheet. Defaults to FALSE
-# Bold.Header.Row = Set bold font for header row. Defaults to FALSE
+# BoldHeaderRow = Set bold font for header row. Defaults to FALSE
+# ReadOnly = Set each worksheet to read only (protected) mode. Defaults to FALSE
 # FreezeRow = Set row to freeze for scrolling
 # FreezeCol = Set col to freeze for scrolling
-# Encoding = character encoding. Either "UTF-8" (default) or "latin1" (aka "iso-8859-1") or "cp1252" (Windows)
+# Encoding = character encoding. "UTF-8" (default) or "latin1" (aka "iso-8859-1") or "cp1252" (Windows)
 
 # Spreadsheet::WriteExcel 
 # https://github.com/jmcnamara/spreadsheet-writeexcel
@@ -49,6 +50,7 @@ my $verbose = "FALSE";
 my $AdjWidth = "FALSE";
 my $AutoFilter = "FALSE";
 my $BoldHeaderRow = "FALSE";
+my $ReadOnly = "FALSE";
 my $FreezeRow = 0;
 my $FreezeCol = 0;
 my $Encoding = "UTF-8";
@@ -59,6 +61,7 @@ GetOptions ('CSVpath=s' => \$CSVPath,
             'AdjWidth=s' => \$AdjWidth,
             'AutoFilter=s' => \$AutoFilter,
             'BoldHeaderRow=s' => \$BoldHeaderRow,
+            'ReadOnly=s' => \$ReadOnly,
             'FreezeRow=i' => \$FreezeRow,
             'FreezeCol=i' => \$FreezeCol,
 	    'Encoding=s' => \$Encoding,
@@ -79,6 +82,13 @@ if ($Encoding eq "UTF-8") {
   $Encode = "<:encoding(cp1252)";
 }
 
+# Special case handling for Perl as installed
+# by RTools 4.x, which is from MSYS2 and is Cygwin
+# based. Thus, change newline handling from LF (Cygwin) to
+# CRLF (Windows) by appending to $Encode.
+# OS ($^O) will show 'msys' rather than Windows
+$Encode .= ":crlf" if $^O eq 'msys';
+
 
 
 
@@ -401,6 +411,10 @@ foreach my $FileName (@FileNames) {
     $WorkSheet->autofilter(0, 0, $Row - 1, $Column - 1);
   }
 
+  if ($ReadOnly eq "TRUE") {
+    $WorkSheet->protect();
+  }
+
   if (($FreezeRow > 0) || ($FreezeCol > 0)) {
     $WorkSheet->freeze_panes($FreezeRow, $FreezeCol);
   }
